"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const swaggerlint_1 = require("./swaggerlint");
const config_1 = require("./utils/config");
const swaggerfile_1 = require("./utils/swaggerfile");
const utils_1 = require("./utils");
const name = 'swaggerlint-core';
function preLintError(msg) {
    return {
        code: 1,
        errors: [{ name, msg, location: [] }],
        schema: undefined,
    };
}
function cli(opts) {
    return __awaiter(this, void 0, void 0, function* () {
        let errors = [];
        let schema;
        const { config, error: configError } = config_1.getConfig(opts.config);
        if (configError) {
            return preLintError(configError);
        }
        const [urlOrPath] = opts._;
        if (!urlOrPath) {
            return preLintError('Neither url nor path were provided for your swagger scheme');
        }
        /**
         * validate config.extends
         */
        if ('extends' in config &&
            config.extends &&
            Array.isArray(config.extends)) {
            if (!config.extends.every(e => typeof e === 'string')) {
                return preLintError('Every value in `extends` has to be a string');
            }
        }
        /**
         * handling `swagger-lint https://...`
         */
        if (urlOrPath.startsWith('http')) {
            const url = urlOrPath;
            utils_1.log(`fetching for ${url}`);
            const swaggerFromUrl = yield swaggerfile_1.getSwaggerByUrl(url).catch((e) => {
                utils_1.log('error fetching url');
                utils_1.log(e);
                return null;
            });
            if (swaggerFromUrl === null) {
                return preLintError('Cannot fetch swagger scheme from the provided url');
            }
            else {
                utils_1.log(`got response`);
                schema = Object.freeze(swaggerFromUrl);
                errors = swaggerlint_1.swaggerlint(swaggerFromUrl, config);
            }
        }
        else {
            /**
             * handling `swagger-lint /path/to/swagger.json`
             */
            const result = swaggerfile_1.getSwaggerByPath(urlOrPath);
            if ('error' in result) {
                return preLintError(result.error);
            }
            schema = Object.freeze(result.swagger);
            errors = swaggerlint_1.swaggerlint(result.swagger, config);
        }
        return {
            errors,
            code: errors.length ? 1 : 0,
            schema,
        };
    });
}
exports.cli = cli;
