"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const case_1 = __importDefault(require("case"));
const utils_1 = require("../../utils");
const name = 'object-prop-casing';
const rule = {
    name,
    visitor: {
        SchemaObject: ({ node, report, setting, location }) => {
            if (typeof setting === 'boolean')
                return;
            const [settingCasingName, opts = {}] = setting;
            const IGNORE_PROPERTIES = new Set(Array.isArray(opts.ignore) ? opts.ignore : []);
            if (typeof settingCasingName === 'string' &&
                utils_1.isValidCaseName(settingCasingName)) {
                const validPropCases = utils_1.validCases[settingCasingName];
                if (utils_1.isRef(node))
                    return;
                if ('properties' in node && node.properties) {
                    Object.keys(node.properties).forEach(propName => {
                        if (IGNORE_PROPERTIES.has(propName))
                            return;
                        const propCase = case_1.default.of(propName);
                        if (!validPropCases.has(propCase)) {
                            const correctVersion = settingCasingName in utils_1.validCases
                                ? case_1.default[settingCasingName](propName)
                                : '';
                            report(`Property "${propName}" has wrong casing.${correctVersion
                                ? ` Should be "${correctVersion}".`
                                : ''}`, [...location, 'properties']);
                        }
                    });
                }
                return;
            }
        },
    },
    isValidSetting: option => {
        if (typeof option !== 'object')
            return false;
        const [first, second] = option;
        const isValidFirstItem = first in utils_1.validCases;
        if (!isValidFirstItem)
            return false;
        if (option.length === 1)
            return true;
        if (utils_1.isObject(second)) {
            const { ignore } = second;
            if (!Array.isArray(ignore))
                return false;
            const isEachIgnoreItemString = ignore.every((x) => typeof x === 'string');
            if (!isEachIgnoreItemString) {
                return { msg: 'Each item in "ignore" has to be a string.' };
            }
            return true;
        }
        else
            return false;
    },
    defaultSetting: ['camel'],
};
exports.default = rule;
