"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mime_db_1 = __importDefault(require("mime-db"));
const name = 'only-valid-mime-types';
function isValidMimeType(maybeMime) {
    return maybeMime in mime_db_1.default;
}
function onlyValidMimeTypeCheck({ node, report, location }) {
    const { consumes, produces } = node;
    if (consumes) {
        consumes.forEach((mType, i) => {
            if (!isValidMimeType(mType)) {
                report(`"${mType}" is not a valid mime type.`, [
                    ...location,
                    'consumes',
                    String(i),
                ]);
            }
        });
    }
    if (produces) {
        produces.forEach((mType, i) => {
            if (!isValidMimeType(mType)) {
                report(`"${mType}" is not a valid mime type.`, [
                    ...location,
                    'produces',
                    String(i),
                ]);
            }
        });
    }
}
const rule = {
    name,
    visitor: {
        SwaggerObject: onlyValidMimeTypeCheck,
        OperationObject: onlyValidMimeTypeCheck,
    },
};
exports.default = rule;
