import * as Swagger from './swagger';
import * as OpenAPI from './openapi';
export declare type CaseName = 'camel' | 'snake' | 'kebab' | 'constant' | 'pascal';
export declare type CliOptions = {
    _: string[];
    version?: string | boolean;
    v?: string | boolean;
    config?: string;
};
declare type ExitCode = 0 | 1;
export declare type CliResult = {
    code: ExitCode;
    errors: LintError[];
    schema: Swagger.SwaggerObject | OpenAPI.OpenAPIObject | void;
};
declare type AbstractObject = Record<string, unknown>;
declare type SwaggerlintRuleSetting = [string, AbstractObject] | [string] | boolean;
export declare type ConfigIgnore = {
    definitions?: string[];
    paths?: string[];
};
export declare type SwaggerlintConfig = {
    extends?: string[];
    rules: {
        [ruleName: string]: SwaggerlintRuleSetting;
    };
    ignore?: ConfigIgnore;
};
export declare type LintError = {
    name: string;
    msg: string;
    location: string[];
};
export declare type Report = (msg: string, location?: string[]) => void;
declare type RuleVisitorFunction<T> = (a: {
    node: T;
    location: string[];
    report: Report;
    setting: SwaggerlintRuleSetting;
}) => void;
export declare type SwaggerVisitorName = keyof SwaggerRuleVisitor;
declare type SwaggerRuleVisitor = Partial<{
    SwaggerObject: RuleVisitorFunction<Swagger.SwaggerObject>;
    InfoObject: RuleVisitorFunction<Swagger.InfoObject>;
    PathsObject: RuleVisitorFunction<Swagger.PathsObject>;
    DefinitionsObject: RuleVisitorFunction<Swagger.DefinitionsObject>;
    ParametersDefinitionsObject: RuleVisitorFunction<Swagger.ParametersDefinitionsObject>;
    ResponsesDefinitionsObject: RuleVisitorFunction<Swagger.ResponsesDefinitionsObject>;
    SecurityDefinitionsObject: RuleVisitorFunction<Swagger.SecurityDefinitionsObject>;
    SecuritySchemeObject: RuleVisitorFunction<Swagger.SecuritySchemeObject>;
    ScopesObject: RuleVisitorFunction<Swagger.ScopesObject>;
    SecurityRequirementObject: RuleVisitorFunction<Swagger.SecurityRequirementObject>;
    TagObject: RuleVisitorFunction<Swagger.TagObject>;
    ExternalDocumentationObject: RuleVisitorFunction<Swagger.ExternalDocumentationObject>;
    ContactObject: RuleVisitorFunction<Swagger.ContactObject>;
    LicenseObject: RuleVisitorFunction<Swagger.LicenseObject>;
    PathItemObject: RuleVisitorFunction<Swagger.PathItemObject>;
    OperationObject: RuleVisitorFunction<Swagger.OperationObject>;
    ParameterObject: RuleVisitorFunction<Swagger.ParameterObject>;
    ResponsesObject: RuleVisitorFunction<Swagger.ResponsesObject>;
    ResponseObject: RuleVisitorFunction<Swagger.ResponseObject>;
    SchemaObject: RuleVisitorFunction<Swagger.SchemaObject>;
    XMLObject: RuleVisitorFunction<Swagger.XMLObject>;
    HeadersObject: RuleVisitorFunction<Swagger.HeadersObject>;
    HeaderObject: RuleVisitorFunction<Swagger.HeaderObject>;
    ItemsObject: RuleVisitorFunction<Swagger.ItemsObject>;
    ExampleObject: RuleVisitorFunction<Swagger.ExampleObject>;
}>;
export declare type OpenAPIVisitorName = keyof OpenAPIRuleVisitor;
declare type OpenAPIRuleVisitor = Partial<{
    DiscriminatorObject: RuleVisitorFunction<OpenAPI.DiscriminatorObject>;
    XMLObject: RuleVisitorFunction<OpenAPI.XMLObject>;
    SchemaObject: RuleVisitorFunction<OpenAPI.SchemaObject>;
    SpecificationExtensions: RuleVisitorFunction<OpenAPI.SpecificationExtensions>;
    LicenseObject: RuleVisitorFunction<OpenAPI.LicenseObject>;
    ContactObject: RuleVisitorFunction<OpenAPI.ContactObject>;
    InfoObject: RuleVisitorFunction<OpenAPI.InfoObject>;
    ServerVariableObject: RuleVisitorFunction<OpenAPI.ServerVariableObject>;
    ServerObject: RuleVisitorFunction<OpenAPI.ServerObject>;
    ExternalDocumentationObject: RuleVisitorFunction<OpenAPI.ExternalDocumentationObject>;
    TagObject: RuleVisitorFunction<OpenAPI.TagObject>;
    SecurityRequirementObject: RuleVisitorFunction<OpenAPI.SecurityRequirementObject>;
    ReferenceObject: RuleVisitorFunction<OpenAPI.ReferenceObject>;
    CallbackObject: RuleVisitorFunction<OpenAPI.CallbackObject>;
    RuntimeExpression: RuleVisitorFunction<OpenAPI.RuntimeExpression>;
    LinkObject: RuleVisitorFunction<OpenAPI.LinkObject>;
    OAuthFlowObject: RuleVisitorFunction<OpenAPI.OAuthFlowObject>;
    OAuthFlowsObject: RuleVisitorFunction<OpenAPI.OAuthFlowsObject>;
    SecuritySchemeObject: RuleVisitorFunction<OpenAPI.SecuritySchemeObject>;
    ExampleObject: RuleVisitorFunction<OpenAPI.ExampleObject>;
    EncodingObject: RuleVisitorFunction<OpenAPI.EncodingObject>;
    MediaTypeObject: RuleVisitorFunction<OpenAPI.MediaTypeObject>;
    RequestBodyObject: RuleVisitorFunction<OpenAPI.RequestBodyObject>;
    ParameterObject: RuleVisitorFunction<OpenAPI.ParameterObject>;
    HeaderObject: RuleVisitorFunction<OpenAPI.HeaderObject>;
    ResponseObject: RuleVisitorFunction<OpenAPI.ResponseObject>;
    ResponsesObject: RuleVisitorFunction<OpenAPI.ResponsesObject>;
    OperationObject: RuleVisitorFunction<OpenAPI.OperationObject>;
    PathItemObject: RuleVisitorFunction<OpenAPI.PathItemObject>;
    PathsObject: RuleVisitorFunction<OpenAPI.PathsObject>;
    ComponentsObject: RuleVisitorFunction<OpenAPI.ComponentsObject>;
}>;
declare type SwaggerlintRulePrimitive = {
    name: string;
    visitor: SwaggerRuleVisitor;
};
declare type SwaggerlintRuleWithSetting = SwaggerlintRulePrimitive & {
    /**
     * Verification of valid setting for the rule,
     * no need to verify boolean settings.
     */
    isValidSetting: (setting: SwaggerlintRuleSetting) => boolean | {
        msg: string;
    };
    defaultSetting: SwaggerlintRuleSetting;
};
export declare type SwaggerlintRule = SwaggerlintRulePrimitive | SwaggerlintRuleWithSetting;
export {};
