"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const cosmiconfig_1 = require("cosmiconfig");
const defaultConfig_1 = __importDefault(require("../defaultConfig"));
const pkg = require('../../package.json');
function mergeConfigs(defConf, userConf) {
    var _a, _b;
    return {
        extends: [...((_a = defConf.extends) !== null && _a !== void 0 ? _a : []), ...((_b = userConf.extends) !== null && _b !== void 0 ? _b : [])],
        rules: Object.assign(Object.assign({}, defConf.rules), userConf.rules),
        ignore: Object.assign({}, userConf.ignore),
    };
}
// workaround for extends keyword
function omitExtends(_a) {
    var { 
    /* eslint-disable @typescript-eslint/no-unused-vars */
    extends: ext } = _a, rest = __rest(_a, ["extends"]);
    return rest;
}
function resolveConfigExtends(baseConfig) {
    const processedConfigs = new Set([]);
    const toBeMergedConfigs = [omitExtends(baseConfig)];
    function resolveExtends(conf) {
        [...conf.extends].reverse().forEach(function resolveEachName(name) {
            if (typeof name !== 'string') {
                throw 'Every item in "extends" has to be a string.';
            }
            let resolvedName;
            try {
                resolvedName = require.resolve(name);
            }
            catch (e) {
                if (e.code && e.code === 'MODULE_NOT_FOUND') {
                    throw `"${name}" in extends of your config cannot be found. Make sure it exists in your node_modules.`;
                }
                else {
                    throw e;
                }
            }
            if (processedConfigs.has(resolvedName))
                return;
            processedConfigs.add(resolvedName);
            const nextConf = require(name);
            if (nextConf.extends)
                resolveExtends(nextConf);
            toBeMergedConfigs.unshift(nextConf);
        });
    }
    resolveExtends(baseConfig);
    /**
     * default config is always the base of any config
     */
    const result = toBeMergedConfigs.reduce((acc, conf) => mergeConfigs(acc, conf), defaultConfig_1.default);
    return result;
}
exports.resolveConfigExtends = resolveConfigExtends;
function getConfig(configPath) {
    const cosmiconfig = cosmiconfig_1.cosmiconfigSync(pkg.name);
    if (configPath) {
        const cosmiResult = cosmiconfig.load(path_1.default.resolve(configPath));
        const loadedConfig = cosmiResult === null || cosmiResult === void 0 ? void 0 : cosmiResult.config;
        if (loadedConfig) {
            const config = loadedConfig.extends
                ? resolveConfigExtends(loadedConfig)
                : mergeConfigs(defaultConfig_1.default, loadedConfig);
            return {
                config,
                error: null,
            };
        }
        else {
            return {
                config: defaultConfig_1.default,
                error: 'Swaggerlint config with a provided path does not exits.',
            };
        }
    }
    else {
        const cosmiResult = cosmiconfig.search();
        const lookedupConfig = cosmiResult === null || cosmiResult === void 0 ? void 0 : cosmiResult.config;
        if (lookedupConfig) {
            if (lookedupConfig.extends) {
                try {
                    return {
                        config: resolveConfigExtends(lookedupConfig),
                        error: null,
                    };
                }
                catch (e) {
                    return {
                        config: defaultConfig_1.default,
                        error: e,
                    };
                }
            }
            else {
                return {
                    config: mergeConfigs(defaultConfig_1.default, lookedupConfig),
                    error: null,
                };
            }
        }
        else {
            return {
                config: defaultConfig_1.default,
                error: null,
            };
        }
    }
}
exports.getConfig = getConfig;
