"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const isDev = process.env.NODE_ENV === 'development';
exports.log = isDev
    ? (x) => console.log(`--> ${x}`)
    : () => null;
function isRef(arg) {
    return typeof arg.$ref === 'string';
}
exports.isRef = isRef;
function isSchemaObjectAllOfObject(arg) {
    return Array.isArray(arg.allOf);
}
exports.isSchemaObjectAllOfObject = isSchemaObjectAllOfObject;
function isObject(arg) {
    return typeof arg === 'object' && arg !== null && !Array.isArray(arg);
}
exports.isObject = isObject;
/**
 * TODO: extract swagger v2 specific utils into separate file
 */
const swaggerVisitorSet = new Set([
    'SwaggerObject',
    'InfoObject',
    'PathsObject',
    'DefinitionsObject',
    'ParametersDefinitionsObject',
    'ResponsesDefinitionsObject',
    'SecurityDefinitionsObject',
    'SecuritySchemeObject',
    'ScopesObject',
    'SecurityRequirementObject',
    'TagObject',
    'ExternalDocumentationObject',
    'ContactObject',
    'LicenseObject',
    'PathItemObject',
    'OperationObject',
    'ParameterObject',
    'ResponsesObject',
    'ResponseObject',
    'SchemaObject',
    'XMLObject',
    'HeadersObject',
    'HeaderObject',
    'ItemsObject',
    'ExampleObject',
]);
function isValidSwaggerVisitorName(name) {
    return swaggerVisitorSet.has(name);
}
exports.isValidSwaggerVisitorName = isValidSwaggerVisitorName;
exports.validCases = {
    camel: new Set(['camel', 'lower']),
    constant: new Set(['constant']),
    kebab: new Set(['kebab', 'lower']),
    pascal: new Set(['pascal']),
    snake: new Set(['snake', 'lower']),
};
function isValidCaseName(name) {
    return name in exports.validCases;
}
exports.isValidCaseName = isValidCaseName;
function hasKey(key, obj) {
    return key in obj;
}
exports.hasKey = hasKey;
function isSwaggerObject(arg) {
    return isObject(arg) && hasKey('swagger', arg) && arg.swagger === '2.0';
}
exports.isSwaggerObject = isSwaggerObject;
