"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_get_1 = __importDefault(require("lodash.get"));
const kleur_1 = require("kleur");
const PAD = 6;
function shallowStringify(schema, location) {
    let topLevelObject = true;
    const objToStringify = lodash_get_1.default(schema, location);
    const stringifiedObj = JSON.stringify(objToStringify, (_, value) => {
        if (Array.isArray(value)) {
            return `Array(${value.length})`;
        }
        if (typeof value === 'object' && value !== null) {
            return topLevelObject
                ? ((topLevelObject = false), value)
                : 'Object';
        }
        return value;
    }, PAD + 2);
    return kleur_1.grey((stringifiedObj || '')
        .split('\n')
        .map((x) => x.padStart(PAD + 1, ' '))
        .join('\n'));
}
function toOneLinerFormat({ msg, name, location }, swagger) {
    const hasLocation = location.length;
    const locationInfo = hasLocation ? ` in ${location.join('.')}` : '';
    const ruleName = kleur_1.dim(name);
    return [
        `${kleur_1.red('error')}${locationInfo}`,
        ruleName.padStart(ruleName.length + PAD, ' '),
        msg.padStart(msg.length + PAD, ' '),
        hasLocation && swagger && shallowStringify(swagger, location),
    ]
        .filter(Boolean)
        .join('\n');
}
function logErrors(errors, swagger) {
    console.log(errors.map(x => toOneLinerFormat(x, swagger)).join('\n'));
    console.log('\n');
    const hasErrs = !!errors.length;
    console.log(kleur_1.bold(`You have ${errors.length} error${hasErrs ? 's' : ''}.`));
}
exports.logErrors = logErrors;
