import { Swagger, LintError, ConfigIgnore } from './types';
declare type OneOrNone<T> = [T] | [];
declare type NodeWithLocation<T> = {
    node: T;
    location: string[];
};
declare type Visitors = {
    SwaggerObject: [NodeWithLocation<Swagger.SwaggerObject>];
    InfoObject: [NodeWithLocation<Swagger.InfoObject>];
    PathsObject: [NodeWithLocation<Swagger.PathsObject>];
    DefinitionsObject: OneOrNone<NodeWithLocation<Swagger.DefinitionsObject>>;
    ParametersDefinitionsObject: OneOrNone<NodeWithLocation<Swagger.ParametersDefinitionsObject>>;
    ResponsesDefinitionsObject: OneOrNone<NodeWithLocation<Swagger.ResponsesDefinitionsObject>>;
    SecurityDefinitionsObject: OneOrNone<NodeWithLocation<Swagger.SecurityDefinitionsObject>>;
    SecuritySchemeObject: NodeWithLocation<Swagger.SecuritySchemeObject>[];
    ScopesObject: NodeWithLocation<Swagger.ScopesObject>[];
    SecurityRequirementObject: NodeWithLocation<Swagger.SecurityRequirementObject>[];
    TagObject: NodeWithLocation<Swagger.TagObject>[];
    ExternalDocumentationObject: NodeWithLocation<Swagger.ExternalDocumentationObject>[];
    ContactObject: OneOrNone<NodeWithLocation<Swagger.ContactObject>>;
    LicenseObject: OneOrNone<NodeWithLocation<Swagger.LicenseObject>>;
    PathItemObject: NodeWithLocation<Swagger.PathItemObject>[];
    OperationObject: NodeWithLocation<Swagger.OperationObject>[];
    ParameterObject: NodeWithLocation<Swagger.ParameterObject>[];
    ResponsesObject: NodeWithLocation<Swagger.ResponsesObject>[];
    ResponseObject: NodeWithLocation<Swagger.ResponseObject>[];
    SchemaObject: NodeWithLocation<Swagger.SchemaObject>[];
    XMLObject: NodeWithLocation<Swagger.XMLObject>[];
    HeadersObject: NodeWithLocation<Swagger.HeadersObject>[];
    HeaderObject: NodeWithLocation<Swagger.HeaderObject>[];
    ItemsObject: NodeWithLocation<Swagger.ItemsObject>[];
    ExampleObject: NodeWithLocation<Swagger.ExampleObject>[];
};
declare type WalkerResult = {
    visitors: Visitors;
} | {
    errors: LintError[];
};
declare function walker(swagger: Swagger.SwaggerObject, ignore?: ConfigIgnore): WalkerResult;
export default walker;
